==> bookmarkbridge_0.72.orig.tar.gz: bookmarkbridge-0.72/bookmarkbridge/dlgbrowsers.h <==
/***************************************************************************
                          dlgbrowsers.h  -  description
                             -------------------
    begin                : Sat Nov 16 2002
    copyright            : (C) 2002 by Ken Schenke
    email                : kenschenke at yahoo dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   In addition, as a special exception, Ken Schenke gives permission to  *
 *   link the code of this program with the Qt non-commercial edition (or  *
 *   with modified versions of the Qt non-commercial edition that use the  *
 *   same license as the Qt non-commercial edition, and distribute linked  *
 *   combinations including the two.  You must obey the GNU General Public *
 *   License in all respects for all of the code used other than the Qt    *
 *   Non-Commercial edition.  If you modify this file, you may extend this *
 *   exception to your version of the file, but you are not obligated to   *
 *   do so.  If you do not wish to do so, delete this exception statement  *
 *   from your version.                                                    *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGBROWSERS_H
#define DLGBROWSERS_H

#include "dlgbrowsersbase.h"
#include "bknode.h"

/***************************************************************************
 *                                                                         *
 *   The DlgBrowsers class represents a dialog box used to list the        *
 *   browsers supported by BookmarkBridge, allowing the user to pick one.  *
 *                                                                         *
 ***************************************************************************/

class DlgBrowsers : public DlgBrowsersBase
{
	Q_OBJECT
public:
	DlgBrowsers( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags f = 0 );
	virtual ~DlgBrowsers();

	virtual void listSelectionChanged(void);

	BRWSTYPE browser;	// BrowserNum of the currently selected browser

private:
	void    RefreshList(void);
};

#endif  // end of DLGBROWSERS_H

==> bookmarkbridge_0.76.orig.tar.gz: bookmarkbridge-0.76/bookmarkbridge/dlgbrowsers.h <==
/***************************************************************************
                          dlgbrowsers.h  -  description
                             -------------------
    begin                : Sat Nov 16 2002
    copyright            : (C) 2002 by Ken Schenke
    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
 *   02110-1301, USA                                                       *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGBROWSERS_H
#define DLGBROWSERS_H

#include <QDialog>

#include "ui_dlgbrowsers.h"
#include "bknode.h"

/***************************************************************************
 *                                                                         *
 *   The DlgBrowsers class represents a dialog box used to list the        *
 *   browsers supported by BookmarkBridge, allowing the user to pick one.  *
 *                                                                         *
 ***************************************************************************/

class DlgBrowsers : public QDialog, public Ui::DlgBrowsers
{
	Q_OBJECT;

public:
	DlgBrowsers(QWidget *parent=0);
	virtual ~DlgBrowsers();

	BRWSTYPE browser;	// BrowserNum of the currently selected browser

public slots:
	void on_listBrowsers_currentItemChanged(QListWidgetItem *item);

private:
	void    RefreshList(void);
};

#endif  // end of DLGBROWSERS_H
